<?php
/**
 * @version		$Id: installer.php 3.0 2013-02-15
 * @package		Joomla
 * @subpackage	Content
 * @copyright	Copyright (C) 2013 dejure.org. All rights reserved.
 * @license		This program is free software: you can redistribute it and/or modify
 *				it under the terms of the GNU General Public License as published by
 *				the Free Software Foundation, either version 3 of the License, or
 *				(at your option) any later version.
 *
 *				This program is distributed in the hope that it will be useful,
 *				but WITHOUT ANY WARRANTY; without even the implied warranty of
 *				MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *				GNU General Public License for more details.
 *
 *				You should have received a copy of the GNU General Public License
 *				along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

defined('_JEXEC') or die;

jimport( 'joomla.plugin.plugin' );

class plgContentVernetzungInstallerScript
{
	private $djo_table = 'djo_vernetzung_cache';
	private $db = null;
	/**
	 * Constructor
	 *
	 * @param   JAdapterInstance  $adapter  The object responsible for running this script
	 */
	public function plgContentVernetzungInstallerScript(JAdapterInstance $adapter) {
		$this->db = JFactory::getDbo();
		$query = "DROP TABLE IF EXISTS ".$this->db->quoteName($this->djo_table);
		$this->db->setQuery($query);
		$this->db->query();
	}

	/**
	 * Called before any type of action
	 *
	 * @param   string  $route  Which action is happening (install|uninstall|discover_install)
	 * @param   JAdapterInstance  $adapter  The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	//public function preflight($route, JAdapterInstance $adapter);

	/**
	 * Called after any type of action
	 *
	 * @param   string  $route  Which action is happening (install|uninstall|discover_install)
	 * @param   JAdapterInstance  $adapter  The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	//public function postflight($route, JAdapterInstance $adapter);

	/**
	 * Called on installation
	 *
	 * @param   JAdapterInstance  $adapter  The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	public function install(JAdapterInstance $adapter) {
		$query = "CREATE TABLE ".$this->db->quoteName($this->djo_table)." (
			schluessel varchar(32),
			text mediumtext NOT NULL,
			gespeichert datetime NOT NULL default '0000-00-00 00:00:00',
			UNIQUE KEY ID (schluessel)
		);";
		$this->db->setQuery($query);
		return $this->db->query();
	}

	/**
	 * Called on update
	 *
	 * @param   JAdapterInstance  $adapter  The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	public function update(JAdapterInstance $adapter) {
		$query = "DROP TABLE IF EXISTS TABLE ".$this->db->quoteName($this->djo_table).";
		CREATE TABLE ".$this->db->quoteName($this->djo_table)." (
			schluessel varchar(32),
			text mediumtext NOT NULL,
			gespeichert datetime NOT NULL default '0000-00-00 00:00:00',
			UNIQUE KEY ID (schluessel)
		);";
		$this->db->setQuery($query);
		return $this->db->query();
	}

	/**
	 * Called on uninstallation
	 *
	 * @param   JAdapterInstance  $adapter  The object responsible for running this script
	 */
	public function uninstall(JAdapterInstance $adapter) {
		$query = "DROP TABLE IF EXISTS ".$this->db->quoteName($this->djo_table);
		$this->db->setQuery($query);
		return $this->db->query();
	}
}

?>
